@@ -220,11 +220,11 @@ class NavSoapClient():
         session.auth = HTTPBasicAuth(self.nav_user, self.nav_password)
 
         soap_service_url = self.nav_soap_service + \
-            self.nav_company + "/Codeunit/GetItemImageWS"
+            self.nav_company + "/Codeunit/MfgFunctionsWS"
         client = Client(soap_service_url, transport=Transport(
             session=session, cache=SqliteCache()))
 
-        soap_response = client.service.GetItemImage(itemNo=item_number)
+        soap_response = client.service.GetItemImageMS(itemNo=item_number)
 
         serialized_response = serialize_object(soap_response)
         return serialized_response
